SetupConfig class

Constructors

SetupConfig({String router = '', String routerApiKey = '', String siteUrl = '', String upgradeUrl = '', String compute = 'auto', String hfToken = '', String modelscopeApiToken = ''})

Properties

compute String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hfToken String
getter/setter pair
modelscopeApiToken String
getter/setter pair
router String
getter/setter pair
routerApiKey String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siteUrl String
getter/setter pair
upgradeUrl String
getter/setter pair

Methods

copy() SetupConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited